//////////////////////////////////////////////////////////////////////////////
//  Author : florent robinet (LAL - Orsay): robinet@lal.in2p3.fr
//////////////////////////////////////////////////////////////////////////////
#include "Streams.h"

using namespace std;

int usage(){
    cerr<<"This program computes the detector response to a gravitational wave"<<endl;
    cerr<<"with the following parameters:"<<endl;
    cerr<<"ra  = source right ascension [rad]"<<endl;
    cerr<<"dec = source declination [rad]"<<endl;
    cerr<<"psi = source polarization angle [rad]"<<endl;
    cerr<<"gps = GW geocentric GPS time"<<endl;
    cerr<<endl;
    cerr<<"usage:"<<endl;
    cerr<<"printdetresponse.exe [det prefix] [ra] [dec] [psi] [gps]"<<endl; 
    cerr<<endl;
    cerr<<"  [det prefix] : detector prefix. Must a LV detector."<<endl; 
    return 1;
}

int main (int argc, char* argv[]){

  // check the output directory
  if(argc!=6) return usage();

  // get det prefix
  string detprefix=(string)argv[1];
  string streamname=detprefix+":whatever";

  //
  double ra = atof(argv[2]);
  double dec = atof(argv[3]);
  double psi = atof(argv[4]);
  double geo_gps = atof(argv[5]);

  // stream
  Streams *S = new Streams(streamname, 0);
  if(S->GetDetIndex()<0){
    cerr<<"Not a LV detector"<<endl;
    return 1;
  }

  // det time
  double det_gps = S->GetLocalTime(ra,dec,geo_gps);

  // det response
  double fplus, fcross;
  S->GetDetAMResponse(fplus, fcross, ra, dec, psi, GreenwichMeanSiderealTime(det_gps));

  cout<<endl;
  cout<<DET_NAME[S->GetDetIndex()]<<endl;
  cout<<"Local time = "<<setprecision(15)<<det_gps<<endl;
  cout<<"GMST       = "<<setprecision(15)<<GreenwichMeanSiderealTime(det_gps)<<endl;
  cout<<"F+         = "<<fplus<<endl;
  cout<<"Fx         = "<<fcross<<endl;
  cout<<endl;


  return 0;
}
